@@ -1,12 +1,13 @@
 package Parse::BBCode::Markdown;
-$Parse::BBCode::Markdown::VERSION = '0.15_002'; # TRIAL
-
-$Parse::BBCode::Markdown::VERSION = '0.15002';use strict;
+use strict;
 use warnings;
+use Data::Dumper;
 use Carp qw(croak carp);
 use URI::Escape;
 use base qw/ Parse::BBCode /;
 
+our $VERSION = '0.01';
+
 my %default_tags = (
     'b'     => '*%s*',
     'i'     => '__%s__',
@@ -17,14 +18,13 @@ my %default_tags = (
     'email' => 'url:[%s](mailto:%{email}A)',
     'size'  => '%s',
     'color' => '%s',
-    'list'  => 'block:%{parse}s',
+        'list'  => 'block:%{parse}s',
     '*'     => {
         parse => 1,
-        output => "* %s\n",
+        output => '* %s',
         close => 0,
-        class => 'block',
     },
-    'quote' => {
+    quote => {
         parse => 1,
         class => 'block',
         code => sub {
